package cz.cvut.fel.alg;

import org.junit.runner.JUnitCore;
import org.junit.runner.Result;
import org.junit.runner.notification.Failure;

/**
 * This class tests the binary search tree against test classes. To run tests in
 * NetBeans press shift+F6 or go to test classes and use the same shortcut.
 *
 * @author Petr Ryšavý, Karel Horák
 */
public class Main {
    private static final JUnitCore junit = new JUnitCore();

    public static void main(String[] args) {
        runTest(FibonacciRecursiveTest.class, "Fibonacci recursive");
        runTest(FibonacciDPTest.class, "Fibonacci DP");
        runTest(BinomialRecursiveTest.class, "Binomial coefficient recursive");
        runTest(BinomialDPTest.class, "Binomial coefficient DP");
        runTest(NoStringsRecursiveTest.class, "Number of strings recursive");
        runTest(NoStringsDPTest.class, "Number of strings DP");
    }

    private static void runTest(Class testClass, String comment) {
        System.out.println("--------------------------------------");
        System.out.println(comment);
        long timestamp = System.currentTimeMillis();
        Result result = junit.run(testClass);
        timestamp = System.currentTimeMillis() - timestamp;
        System.out.println("Broken " + result.getFailureCount() + " test cases out of " + result.getRunCount());
        System.out.println("Runtime : "+timestamp+"ms");
        if (result.getFailureCount() != 0) {
            System.out.println("Broken tests:");
            for (Failure f : result.getFailures()) {
                System.out.printf("    %-30s %s\n", f.getDescription().getMethodName(), f.getMessage());
                if(f.getException() != null)
                    System.out.printf("    %-30s %s\n", "", f.getException().getClass().getSimpleName());
            }
        }
    }

}
